---
title: API Reference
---

::: ggml.ggml
    options:
        show_root_full_path: false
        filters:
            - "^ggml_"
            - "^gguf_"
            - "^GGML_"
            - "^GGUF_"

::: ggml.utils